(* PARAMETERS *)

val ordersToCreate = 10000;

val breakPointMaxFulfilledOrders = 5000;

val interarrivaltime = 15.0 * minute;

val maxOrderSize = 4;

val maxPTUpdates = 3;

val paymentRetries = 3;

val orderpoints = 
    1`(100, phone)++
    1`(100, tv)++
    1`(100, laptop)++
    1`(0, desktop);

val uptolevels = 
    1`(250, phone)++
    1`(250, tv)++
    1`(250, laptop)++
    1`(0, desktop);

val reviews = 1`(day, phone)@day++
    1`(day, tv)@day++
    1`(day, laptop)@day++
    1`(8.0*hour, desktop)@(8.0 * hour);

val pickingResources = 1`Senior ++ 2`Junior;

val packingStations = 1`StationA ++ 1`StationB;

val couriers = 1`("Courier A", 15)++1`("Courier B", 10)++1`("Courier C", 5);

(* FUNCTIONS *)

fun initTime() = exp(100.0 * minute);

fun pay(ct:CUSTOMERTYPE, pt:PAYMENTTYPE) = bernoulli(0.9) = 1;

fun cancelOrder() = bernoulli( 5.0 / 100.0 );

fun courierIssue(c:STRING) = bernoulli( 0.5 / 100.0 );

(* TIMING FUNCTIONS *) 

fun paymentDelay(ct:CUSTOMERTYPE, pt:PAYMENTTYPE) =  normal(5.0 * minute, 1.0 * minute);

fun receivePaymentDelay(pt:PAYMENTTYPE) = normal(5.0 * minute, 0.5 * minute);

fun changePaymentDelay() = normal(5.0 * minute, 1.5 * minute);

fun replenishmentDelay() = normal(10.0 * minute, 1.0 * minute);

fun productionTime(phone, n) = normal(day, 4.0 * hour)
    | productionTime(tv, n) =  normal(day, 4.0 * hour)
    | productionTime(laptop, n) = normal(day, 4.0 * hour)
    | productionTime(desktop, n) = normal(4.0 * hour, 4.0 * hour);

fun unloadReplenishmentDelay(n:INT) = 
        let
            val static = 10.0 * minute
            val dynamic = 30.0 * real n
        in
            normal(static + dynamic, 5.0 * minute)
        end;

fun pickingDelay(r:PICKINGRESOURCE) = normal(10.0 * minute, 2.0 * minute);

fun packingDelay(s:PACKINGSTATION) = normal(15.0 * minute, 2.5 * minute);

fun deliveryDelay() = normal(10.0 * minute, 2.0 * minute);

fun createShipmentDelay() = normal(10.0 * minute, 5.0 * minute);

fun loadDelay(c:STRING) = normal(60.0 * minute, 10.0 * minute);

fun headoutDelay() = normal(30.0 * minute, 5.0 * minute);

fun headbackDelay() = normal(30.0 * minute, 10.0 * minute);

fun processOrderDelay(ps:PRODUCTS) = 
        let
            val i = length ps
        in
            real i * normal(10.0 * minute, 0.5 * minute)
        end;

fun completeOrderDelay(ps:PRODUCTS) = 
        let
            val i = length ps
        in
            real i * normal(5.0 * minute, 0.5 * minute)
        end;